#include <stdio.h>
#include <stdlib.h>
#include <roxml.h>

#include "skinsXML.h"
#include "structures.h"

/*!
* \file classesXML.c
* \brief Fichier contenant le code des fonctions d'aquisition des fichiers images.
*/


/*!
 * \fn Skins_Charac* Remplir_Skin_Charac(char *filename)
 * \brief Fonction qui extrait les noms des fichiers images.
 *
 * \return un pointeur sur une collection de noms de fichiers.
 */
Skins_Charac* Remplir_Skin_Charac(char *filename)
{

    FILE* Skins_log = NULL;
    Skins_log = fopen("Skin_XML_log", "w");
    if (Skins_log != NULL)
    {
        fprintf(Skins_log,"Fichier decrivant le deroulement de la procedure d'aquisition des textures personnages\n\n");
        node_t *rootXML, *Skins, *Personnages;
        unsigned int i=0, nb_persos=0;

        rootXML = roxml_load_doc(filename);            /* Ouvre le doc XML et cr le noeud de base */
        Skins = roxml_get_chld(rootXML, NULL, 0);
        Personnages = roxml_get_chld(Skins, NULL, 0);
        nb_persos = roxml_get_chld_nb(Personnages);

        Skins_Charac* Liste_Skins_Charac = NULL;

        Liste_Skins_Charac = malloc(nb_persos * sizeof(Skins_Charac));     /* Allocation de la mmoire ncssaire et test*/
        if (Liste_Skins_Charac == NULL)
        {
            fprintf(Skins_log,"Allocation impossible \n");
            exit(EXIT_FAILURE);
        }
        fprintf(Skins_log,"1) Memoire allouee avec succes \n");
        fprintf(Skins_log,"La memoire allouee fait %d octets\n",nb_persos * sizeof(Skins_Charac));

        /* -----------------------------------------------------------------------------------------------------------------------*/

        for(i=0; i<nb_persos; i++)
        {
            fprintf(Skins_log,"\nChargement de la classe numero %d\n", i+1);

            Skins_Charac Skins_Charac_en_cours;

            node_t* Skin;
            char *id_text, *default_text, *selected_text, *healed_text, *damaged_text;

            Skin = roxml_get_chld(Personnages, NULL, i);
            id_text = roxml_get_content(roxml_get_attr(Skin, "id", 0), NULL, 0, NULL);
            default_text = roxml_get_content(roxml_get_attr(Skin, "f_default", 0), NULL, 0, NULL);
            selected_text = roxml_get_content(roxml_get_attr(Skin, "f_selected", 0), NULL, 0, NULL);
            healed_text = roxml_get_content(roxml_get_attr(Skin, "f_healed", 0), NULL, 0, NULL);
            damaged_text = roxml_get_content(roxml_get_attr(Skin, "f_damaged", 0), NULL, 0, NULL);

            /* Tests
            printf("TEST damaged : %s\n\n",damaged_text);
            printf("TEST healed : %s\n\n",healed_text);
            printf("TEST selected : %s\n\n",selected_text);
            printf("TEST default : %s\n\n",default_text);
            */

            fprintf(Skins_log,"\n ID : %s", damaged_text);
            fprintf(Skins_log,"\n default : %s", default_text);
            fprintf(Skins_log,"\n selected : %s", selected_text);
            fprintf(Skins_log,"\n healed : %s", healed_text);
            fprintf(Skins_log,"\n damaged : %s\n\n", damaged_text);


            strcpy(Skins_Charac_en_cours.charac_id, id_text);
            strcpy(Skins_Charac_en_cours.charac_default, default_text);
            strcpy(Skins_Charac_en_cours.charac_selected, selected_text);
            strcpy(Skins_Charac_en_cours.charac_healed, healed_text);
            strcpy(Skins_Charac_en_cours.charac_damaged, damaged_text);

            Liste_Skins_Charac[i] = Skins_Charac_en_cours;

            /* Tests
            printf("Nom : %s\n\n", Skins_Charac_en_cours.charac_id);
            printf("Healed : %s\n\n", Skins_Charac_en_cours.charac_healed);
            printf("Damaged : %s\n\n", Skins_Charac_en_cours.charac_damaged);
            printf("Selected : %s\n\n", Skins_Charac_en_cours.charac_selected);
            printf("Default : %s\n\n", Skins_Charac_en_cours.charac_default);
            */
        }
        fclose(Skins_log);
        return Liste_Skins_Charac;
    }
    else
    {
        fprintf(stderr,"Impossible d'ouvrir le fichier Skins_XML_log");

    }
}
